package info.aspirecn.iov.sjjh.util;

import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.commons.lang.PatternTools;
import info.aspirecn.iov.sjjh.entity.VehicleHistoryPositionRequestParam;
import org.apache.commons.lang3.StringUtils;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import java.text.SimpleDateFormat;
import java.util.Set;
import java.util.regex.Pattern;

/**
 * @author xusonglin
 * @version V1.0
 **/
public class ValidateParamUtil {
    private static final String DATE_REGEX = "^((([0-9]{3}[1-9]|[0-9]{2}[1-9][0-9]{1}|[0-9]{1}[1-9][0-9]{2}|[1-9][0-9]{3})" +
            "(((0[13578]|1[02])(0[1-9]|[12][0-9]|3[01]))|((0[469]|11)(0[1-9]|[12][0-9]|30))|(02(0[1-9]|[1][0-9]|2[0-8]))))" +
            "|((([0-9]{2})(0[48]|[2468][048]|[13579][26])|((0[48]|[2468][048]|[3579][26])00))0229))" +
            "([0-1]?[0-9]|2[0-3])([0-5][0-9])([0-5][0-9])$";
    private static final String NUMBER_REGEX = "^(0|[1-9]\\d*)$";

    public static boolean validateRequestParams(VehicleHistoryPositionRequestParam requestParam) {
        Pattern datePattern = Pattern.compile(DATE_REGEX);
        Pattern numberPattern = Pattern.compile(NUMBER_REGEX);
        if (!validateParamNullValue(requestParam)) {
            return false;
        } else if (StringUtils.isBlank(requestParam.getPlateNumber())
                || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, requestParam.getPlateNumber())) {
            return false;
        } else if (StringUtils.isBlank(requestParam.getPlateColor())
                || !numberPattern.matcher(requestParam.getPlateColor()).matches()) {
            return false;
        } else if (StringUtils.isBlank(requestParam.getStartTime())
                || !datePattern.matcher(requestParam.getStartTime()).matches()) {
            return false;
        } else if (StringUtils.isBlank(requestParam.getEndTime())
                || !datePattern.matcher(requestParam.getEndTime()).matches()) {
            return false;
        } else {
            return true;
        }
    }

    private static boolean validateParamNullValue(Object jsonResolveObject) {
        ValidatorFactory vf = Validation.buildDefaultValidatorFactory();
        Validator validator = vf.getValidator();
        Set<ConstraintViolation<Object>> set = validator.validate(jsonResolveObject);
        for (ConstraintViolation<Object> con : set) {
            if (StringUtils.isNotBlank(con.getMessage())) {
                return false;
            }
        }
        return true;
    }
}
